@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2022-04-27 16:30:28
+:LastEditTime: 2022-05-18 15:41:38
 :LastEditors: ChenXiaolei
 :Description: StudioBaseHandler
 """
@@ -144,7 +144,7 @@ class StudioBaseHandler(BaseCookieHandler):
             self.set_header("Access-Control-Allow-Origin", origin)
 
         self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
-        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
+        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS,PUT,DELETE")
         self.set_header("Access-Control-Allow-Credentials", "true")
 
     def request_header_token(self):
