@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-22 14:32:40
-:LastEditTime: 2020-12-08 15:48:09
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-01-12 08:36:04
+:LastEditors: HuangJingCan
 :Description: 栏目扩展类
 """
 
@@ -48,13 +48,7 @@ class MenuInfoDto():
 
     @classmethod
     def get_field_list(self):
-        return [
-            'MenuID', 'MenuIcon', 'MenuName', 'ParentID', 'IsShow', 'IsPower',
-            'IDPath', 'ShowCondition', 'CommandParms', 'ButtonColor',
-            'MenuCoteID', 'MenuCoteKey', 'ChildList', 'MenuNamePath',
-            'ApiPath', 'ViewPath', 'ButtonPlace', 'CommandName', 'ActionType',
-            'ActionRender', 'MenuType', 'SortIndex'
-        ]
+        return ['MenuID', 'MenuIcon', 'MenuName', 'ParentID', 'IsShow', 'IsPower', 'IDPath', 'ShowCondition', 'CommandParms', 'ButtonColor', 'MenuCoteID', 'MenuCoteKey', 'ChildList', 'MenuNamePath', 'ApiPath', 'ViewPath', 'ButtonPlace', 'CommandName', 'ActionType', 'ActionRender', 'MenuType', 'SortIndex']
 
 
 class MenuInfoEx(MenuInfo):
@@ -69,13 +63,11 @@ class MenuInfoEx(MenuInfo):
 
         view_path_find_index = menu_info.ViewPath.find("/:")
         if view_path_find_index > 0:
-            menu_info.ViewPathValue = menu_info.ViewPath[
-                0:view_path_find_index]
+            menu_info.ViewPathValue = menu_info.ViewPath[0:view_path_find_index]
         else:
             menu_info.ViewPathValue = menu_info.ViewPath
 
-        menu_cote_key = "$" + menu_info.MenuCoteKey if menu_info.MenuCoteKey.strip(
-        ) != "" else ""
+        menu_cote_key = "$" + menu_info.MenuCoteKey if menu_info.MenuCoteKey.strip() != "" else ""
 
         menu_info.RedirctPathValue = f"/{menu_info.MenuID}{menu_cote_key}{menu_info.ViewPathValue.lower()}"
 
@@ -174,19 +166,16 @@ class MenuInfoModelEx(MenuInfoModel):
         if parent_power_menu:
             parent_power_menu.HaveChild = 1
             self.update(parent_power_menu)
-            menu_info.IDPath = "," + parent_power_menu.IDPath.strip(
-                ",") + "," + menu_info.MenuID + ","
+            menu_info.IDPath = "," + parent_power_menu.IDPath.strip(",") + "," + menu_info.MenuID + ","
             menu_info.MenuNamePath = parent_power_menu.MenuNamePath + "," + menu_info.MenuName
             menu_info.Depth = parent_power_menu.Depth + 1
-            menu_info.SortIndex = int(
-                self.get_total("ParentID=%s", params=menu_info.ParentID))
+            menu_info.SortIndex = int(self.get_total("ParentID=%s", params=menu_info.ParentID))
 
         else:
             menu_info.MenuType = 1
             menu_info.IDPath = menu_info.ParentID + "," + menu_info.MenuID + ","
             menu_info.Depth = 1
-            menu_info.SortIndex = int(
-                self.get_total("ParentID=%s", params=[menu_info.ParentID]))
+            menu_info.SortIndex = int(self.get_total("ParentID=%s", params=[menu_info.ParentID]))
 
         self.update(menu_info)
 
@@ -210,14 +199,10 @@ class MenuInfoModelEx(MenuInfoModel):
         :last_editors: HuangJingCan
         """
         if menu_info.MenuNamePath != "":
-            menu_name_list = [
-                i for i in menu_info.MenuNamePath.strip(",").split(",")
-                if i != ""
-            ]
+            menu_name_list = [i for i in menu_info.MenuNamePath.strip(",").split(",") if i != ""]
             menu_name_list.pop()
             if menu_name_list:
-                menu_info.MenuNamePath = "," + ','.join(
-                    menu_name_list) + "," + menu_info.MenuName + ","
+                menu_info.MenuNamePath = "," + ','.join(menu_name_list) + "," + menu_info.MenuName + ","
         menu_info.MenuNamePath = "," + menu_info.MenuName + "," if menu_info.MenuNamePath == "" else menu_info.MenuNamePath
 
         return self.update_entity(menu_info)
@@ -241,38 +226,30 @@ class MenuInfoModelEx(MenuInfoModel):
         """
         menu_info_list = self.get_list(f"IDPath LIKE '%{copy_menu_id}%'")
         if menu_info_list:
-            copy_menu_info = [
-                i for i in menu_info_list if i.MenuID == copy_menu_id
-            ][0]
+            copy_menu_info = [i for i in menu_info_list if i.MenuID == copy_menu_id][0]
             copy_menu_info.MenuType = 2 if copy_menu_info.MenuType == 1 else copy_menu_info.MenuType
             copy_menu_info.MenuID = UUIDHelper.get_uuid()
             copy_menu_info.MenuName += "==复制"
             copy_menu_info.ParentID = stick_menu_id
             copy_menu_info.SortIndex = 0
             self.add(copy_menu_info)
-            self.add_copy_child_menu(copy_menu_id, copy_menu_info.MenuID,
-                                     menu_info_list)
+            self.add_copy_child_menu(copy_menu_id, copy_menu_info.MenuID, menu_info_list)
 
-    def add_copy_child_menu(self, old_parent_id, curr_parent_id,
-                            menu_info_list):
+    def add_copy_child_menu(self, old_parent_id, curr_parent_id, menu_info_list):
         """
         :description: 粘贴子节点
         :param {type} 
         :return: 
         :last_editors: HuangJingCan
         """
-        curr_menu_info_list = [
-            i for i in menu_info_list if i.ParentID == old_parent_id
-        ]
+        curr_menu_info_list = [i for i in menu_info_list if i.ParentID == old_parent_id]
         for curr_menu_info in curr_menu_info_list:
             curr_menu_id = curr_menu_info.MenuID
             curr_menu_info.MenuID = UUIDHelper.get_uuid()
             curr_menu_info.ParentID = curr_parent_id
             curr_menu_info.SortIndex = 0
             self.add(curr_menu_info)
-            self.add_copy_child_menu(
-                curr_menu_id, curr_menu_info.MenuID,
-                [i for i in menu_info_list if i.ParentID == old_parent_id])
+            self.add_copy_child_menu(curr_menu_id, curr_menu_info.MenuID, [i for i in menu_info_list if i.ParentID == old_parent_id])
 
     def update_move(self, move_id, target_id):
         """
@@ -297,10 +274,8 @@ class MenuInfoModelEx(MenuInfoModel):
         update_depth = 1 if not target_menu_info else target_menu_info.Depth
 
         for power_menu in menu_info_list:
-            power_menu.MenuNamePath = power_menu.MenuNamePath.replace(
-                menu_name_path, update_name_path)
-            power_menu.IDPath = power_menu.IDPath.replace(
-                id_path, update_id_path)
+            power_menu.MenuNamePath = power_menu.MenuNamePath.replace(menu_name_path, update_name_path)
+            power_menu.IDPath = power_menu.IDPath.replace(id_path, update_id_path)
             power_menu.Depth = power_menu.Depth - depth + 1 + update_depth
             if power_menu.MenuID == move_id:
                 power_menu.ParentID = target_id
@@ -314,12 +289,7 @@ class MenuInfoModelEx(MenuInfoModel):
             have_child = 1
         self.update_table("HaveChild=%s", "MenuID=%s", [have_child, target_id])
 
-    def update_after_before_move(self,
-                                 move_id,
-                                 target_id,
-                                 top_field_name,
-                                 condition="",
-                                 is_after=True):
+    def update_after_before_move(self, move_id, target_id, top_field_name, condition="", is_after=True):
         """
         :description: 移动
         :param move_id：被移动的菜单id
@@ -337,15 +307,9 @@ class MenuInfoModelEx(MenuInfoModel):
         if move_menu_info.ParentID != target_menu_info.ParentID:
             self.update_move(move_id, target_menu_info.ParentID)
 
-        self.move_record(move_id, target_id, top_field_name, condition,
-                         is_after)
+        self.move_record(move_id, target_id, top_field_name, condition, is_after)
 
-    def move_record(self,
-                    select_id,
-                    target_id,
-                    top_field_name,
-                    condition="",
-                    is_after=True):
+    def move_record(self, select_id, target_id, top_field_name, condition="", is_after=True):
         """
         :description: 向前或者向后移动菜单（通用方法，可移动到base_model）
         :param select_id：被移动的菜单id
@@ -360,16 +324,12 @@ class MenuInfoModelEx(MenuInfoModel):
         select_sort_id = 0
         primary_key = MenuInfo().get_primary_key()
         table_name = MenuInfo().__str__()
-        dict_select_sort_id = self.get_dict(f"{primary_key}=%s",
-                                            field=top_field_name,
-                                            params=select_id)
+        dict_select_sort_id = self.get_dict(f"{primary_key}=%s", field=top_field_name, params=select_id)
         if dict_select_sort_id:
             select_sort_id = int(dict_select_sort_id[top_field_name])
 
         target_sort_id = 0
-        dict_target_sort_id = self.get_dict(f"{primary_key}=%s",
-                                            field=top_field_name,
-                                            params=target_id)
+        dict_target_sort_id = self.get_dict(f"{primary_key}=%s", field=top_field_name, params=target_id)
         if dict_target_sort_id:
             target_sort_id = int(dict_target_sort_id[top_field_name])
 
@@ -419,3 +379,18 @@ class MenuInfoModelEx(MenuInfoModel):
                 sort_info["sort_value"] = int(dr[top_field_name])
             obj_list.append(sort_info)
         return obj_list
+
+    def delete(self, menu_id):
+        """
+        :description: 删除栏目
+        :param menu_id:栏目id
+        :return bool
+        :last_editors: HuangJingCan
+        """
+        menu_info = self.get_entity_by_id(menu_id)
+        if not menu_info:
+            return 0
+        count = self.del_entity("IDPath like '" + menu_info.IDPath + "%'")
+        have_child = 1 if self.get_total("ParentID=%s", params=[menu_info.ParentID]) > 0 else 0
+        self.update_table("HaveChild=%s", "ParentID=%s", [have_child, menu_info.ParentID])
+        return count
\ No newline at end of file
