@@ -2,8 +2,8 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-12-07 19:12:00
-:LastEditTime: 2020-12-08 18:31:50
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-06-30 19:12:45
+:LastEditors: HuangJingCan
 :Description: 
 """
 class DictUtil:
@@ -44,7 +44,6 @@ class DictUtil:
         if map_dict:
             field_list = model.get_field_list()
             for filed in field_list:
-                if filed in map_dict:
+                if filed in map_dict.keys():
                     setattr(model, filed, map_dict[filed])
         return model
-    
\ No newline at end of file
